@@ -71,7 +71,8 @@ enum
 {
   RESPONSE_OPEN  = 1,
   RESPONSE_STOP  = 2,
-  RESPONSE_CLEAR = 3
+  RESPONSE_CLEAR = 3,
+  RESPONSE_CLOSE = 4
 };
 
 G_DEFINE_TYPE (EmpathyFTManager, empathy_ft_manager, G_TYPE_OBJECT);
@@ -695,11 +696,8 @@ static void
 ft_manager_start_transfer (EmpathyFTManager *manager,
                            EmpathyFTHandler *handler)
 {
-  EmpathyFTManagerPriv *priv;
   gboolean is_outgoing;
 
-  priv = GET_PRIV (manager);
-
   is_outgoing = !empathy_ft_handler_is_incoming (handler);
 
   DEBUG ("Start transfer, is outgoing %s",
@@ -816,8 +814,6 @@ ft_manager_open (EmpathyFTManager *manager)
   GtkTreeIter iter;
   GtkTreeModel *model;
   EmpathyFTHandler *handler;
-  char *uri;
-  GFile *file;
   EmpathyFTManagerPriv *priv = GET_PRIV (manager);
 
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
@@ -827,14 +823,19 @@ ft_manager_open (EmpathyFTManager *manager)
 
   gtk_tree_model_get (model, &iter, COL_FT_OBJECT, &handler, -1);
 
-  file = empathy_ft_handler_get_gfile (handler);
-  uri = g_file_get_uri (file);
+  if (empathy_ft_handler_is_completed (handler)){
+    char *uri;
+    GFile *file;
 
-  DEBUG ("Opening URI: %s", uri);
-  empathy_url_show (GTK_WIDGET (priv->window), uri);
+    file = empathy_ft_handler_get_gfile (handler);
+    uri = g_file_get_uri (file);
+
+    DEBUG ("Opening URI: %s", uri);
+    empathy_url_show (GTK_WIDGET (priv->window), uri);
+    g_free (uri);
+  }
 
   g_object_unref (handler);
-  g_free (uri);
 }
 
 static void
@@ -865,11 +866,34 @@ ft_manager_stop (EmpathyFTManager *manager)
   g_object_unref (handler);
 }
 
+static gboolean
+close_window (EmpathyFTManager *manager)
+{
+  EmpathyFTManagerPriv *priv = GET_PRIV (manager);
+
+  DEBUG ("%p", manager);
+
+  /* remove all the completed/cancelled/errored transfers */
+  ft_manager_clear (manager);
+
+  if (g_hash_table_size (priv->ft_handler_to_row_ref) > 0)
+    {
+      /* There is still FTs on flight, just hide the window */
+      DEBUG ("Hiding window");
+      gtk_widget_hide (priv->window);
+      return TRUE;
+    }
+
+  return FALSE;
+}
+
 static void
 ft_manager_response_cb (GtkWidget *widget,
                         gint response,
                         EmpathyFTManager *manager)
 {
+  EmpathyFTManagerPriv *priv = GET_PRIV (manager);
+
   switch (response)
     {
       case RESPONSE_CLEAR:
@@ -881,6 +905,10 @@ ft_manager_response_cb (GtkWidget *widget,
       case RESPONSE_STOP:
         ft_manager_stop (manager);
         break;
+      case RESPONSE_CLOSE:
+        if (!close_window (manager))
+          gtk_widget_destroy (priv->window);
+        break;
       case GTK_RESPONSE_NONE:
       case GTK_RESPONSE_DELETE_EVENT:
         /* Do nothing */
@@ -895,22 +923,7 @@ ft_manager_delete_event_cb (GtkWidget *widget,
                             GdkEvent *event,
                             EmpathyFTManager *manager)
 {
-  EmpathyFTManagerPriv *priv = GET_PRIV (manager);
-
-  DEBUG ("%p", manager);
-
-  /* remove all the completed/cancelled/errored transfers */
-  ft_manager_clear (manager);
-
-  if (g_hash_table_size (priv->ft_handler_to_row_ref) > 0)
-    {
-      /* There is still FTs on flight, just hide the window */
-      DEBUG ("Hiding window");
-      gtk_widget_hide (widget);
-      return TRUE;
-    }
-
-  return FALSE;
+  return close_window (manager);
 }
 
 static void
@@ -922,6 +935,20 @@ ft_manager_destroy_cb (GtkWidget *widget,
   g_object_unref (manager);
 }
 
+static gboolean
+ft_view_button_press_event_cb (GtkWidget *widget,
+                               GdkEventKey *event,
+                               EmpathyFTManager *manager)
+{
+
+  if (event->type != GDK_2BUTTON_PRESS)
+      return FALSE;
+
+  ft_manager_open (manager);
+
+  return FALSE;
+}
+
 static gboolean
 ft_manager_key_press_event_cb (GtkWidget *widget,
                                GdkEventKey *event,
@@ -977,6 +1004,9 @@ ft_manager_build_ui (EmpathyFTManager *manager)
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
   g_signal_connect (selection, "changed",
       G_CALLBACK (ft_manager_selection_changed), manager);
+  g_signal_connect (view, "button-press-event",
+                    G_CALLBACK (ft_view_button_press_event_cb),
+                    manager);
   gtk_tree_view_set_headers_visible (view, TRUE);
   gtk_tree_view_set_enable_search (view, FALSE);
 
